@@ -394,7 +394,7 @@ def download_model_version(model_name, env, folder, metadata={}):
     """
     external_id = find_model_version(model_name, env, metadata)
     if not os.path.isdir(folder):
-        os.mkdir(folder)
+        os.makedirs(folder)
     download_folder(external_id, folder)
     logging.info(f"Downloaded model with {external_id=} to {folder}")
     return external_id
\ No newline at end of file
